@@ -3,7 +3,7 @@
 # Author:  mozman
 # Purpose: svg base element
 # Created: 08.09.2010
-# Copyright (C) 2010, Manfred Moitzi
+# Copyright (c) 2010-2020, Manfred Moitzi
 # License: MIT License
 """
 The **BaseElement** is the root for all SVG elements.
@@ -14,7 +14,7 @@ from svgwrite.etree import etree
 import copy
 
 from svgwrite.params import Parameter
-from svgwrite.utils import AutoID, to_unicode, PYTHON3
+from svgwrite.utils import AutoID
 
 
 class BaseElement(object):
@@ -104,6 +104,10 @@ class BaseElement(object):
     def validator(self):
         return self._parameter.validator
 
+    @validator.setter
+    def validator(self, value):
+        self._parameter.validator = value
+
     @property
     def version(self):
         return self._parameter.get_version()
@@ -181,8 +185,18 @@ class BaseElement(object):
 
         """
         xml = self.get_xml()
+        # required for Python 2 support
         xml_utf8_str = etree.tostring(xml, encoding='utf-8')
         return xml_utf8_str.decode('utf-8')
+        # just Python 3: return etree.tostring(xml, encoding='unicode')
+    
+    def _repr_svg_(self):
+        """ Show SVG in IPython, Jupyter Notebook, and Jupyter Lab
+
+        :return: unicode XML string of this object and all its subelements
+
+        """
+        return self.tostring()
 
     def get_xml(self):
         """ Get the XML representation as `ElementTree` object.
@@ -193,7 +207,7 @@ class BaseElement(object):
         xml = etree.Element(self.elementname)
         if self.debug:
             self.validator.check_all_svg_attribute_values(self.elementname, self.attribs)
-        for attribute, value in self.attribs.items():
+        for attribute, value in sorted(self.attribs.items()):
             # filter 'None' values
             if value is not None:
                 value = self.value_to_string(value)
@@ -215,7 +229,7 @@ class BaseElement(object):
                 self.validator.check_svg_type(value, 'number')
             if isinstance(value, float) and self.profile == 'tiny':
                 value = round(value, 4)
-        return to_unicode(value)
+        return str(value)
 
     def set_desc(self, title=None, desc=None):
         """ Insert a **title** and/or a **desc** element as first subelement.
@@ -239,7 +253,10 @@ class BaseElement(object):
                 if pos == len(self.elements):
                     self.elements.append(metadata)
                     return
-            self.elements.insert(pos, metadata)
+            if self.elements[pos].elementname == 'metadata':
+                self.elements[pos].xml.append(xmldata)
+            else:
+                self.elements.insert(pos, metadata)
 
 
 class Title(object):
@@ -247,7 +264,7 @@ class Title(object):
 
     def __init__(self, text):
         self.xml = etree.Element(self.elementname)
-        self.xml.text = to_unicode(text)
+        self.xml.text = str(text)
 
     def get_xml(self):
         return self.xml
