@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-#coding:utf-8
+# coding:utf-8
 # Author:  mozman
 # Purpose: svg util functions and classes
 # Created: 08.09.2010
@@ -21,26 +21,16 @@
 
 .. autofunction:: rect_top_left_corner
 
+.. autofunction:: pretty_xml
+
 """
-
-import sys
-PYTHON3 = sys.version_info[0] > 2
-from functools import partial
-
-# Python 3 adaption
-if PYTHON3:
-    to_unicode = str
-    basestring = str
-else:
-    def to_unicode(value):
-        return unicode(value, encoding='utf8') if isinstance(value, str) else unicode(value)
-# Python 3 adaption
+import base64
+from pathlib import Path
+from svgwrite.data import pattern
 
 
 def is_string(value):
-    return isinstance(value, basestring)
-
-from svgwrite.data import pattern
+    return isinstance(value, str)
 
 
 def rgb(r=0, g=0, b=0, mode='RGB'):
@@ -62,6 +52,7 @@ def rgb(r=0, g=0, b=0, mode='RGB'):
     ========= =============================================================
 
     """
+
     def percent(value):
         value = float(value)
         if value < 0:
@@ -202,10 +193,10 @@ def rect_top_left_corner(insert, size, pos='top-left'):
         raise ValueError("Invalid vertical position: '%s'" % vert)
 
     if xunit:
-        x = "%s%s" %(x, xunit)
+        x = "%s%s" % (x, xunit)
     if yunit:
-        y = "%s%s" %(y, yunit)
-    return (x, y)
+        y = "%s%s" % (y, yunit)
+    return x, y
 
 
 class AutoID(object):
@@ -225,3 +216,51 @@ class AutoID(object):
         retval = "id%d" % cls._nextid
         cls._nextid += 1
         return retval
+
+
+def pretty_xml(xml_string, indent=2):
+    """
+    Create human readable XML string.
+
+    :param xml_string: input xml string without line breaks and indentation
+    :indent int: how much to indent, by default 2 spaces
+    :return: xml_string with linebreaks and indentation
+
+    """
+    import xml.dom.minidom as minidom
+
+    # check for empty string, len check avoids unnecessary string manipulation with large XML strings
+    if len(xml_string) < 20 and xml_string.strip() == "":
+        return ""
+    xml_tree = minidom.parseString(xml_string)
+    lines = xml_tree.toprettyxml(indent=' ' * indent).split('\n')
+    # remove 1. line = xml declaration
+    return '\n'.join(lines[1:])
+
+
+FONT_MIMETYPES = {
+    'ttf': "application/x-font-ttf",
+    'otf': "application/x-font-opentype",
+    'woff': "application/font-woff",
+    'woff2': "application/font-woff2",
+    'eot': "application/vnd.ms-fontobject",
+    'sfnt': "application/font-sfnt",
+}
+
+
+def font_mimetype(name):
+    return FONT_MIMETYPES[Path(name.lower()).suffix[1:]]
+
+
+def base64_data(data, mimetype):
+    data = base64.b64encode(data).decode()
+    return "data:{mimetype};charset=utf-8;base64,{data}".format(mimetype=mimetype, data=data)
+
+
+def find_first_url(text):
+    import re
+    result = re.findall(r"url\((.*?)\)", text)
+    if result:
+        return result[0]
+    else:
+        return None
